@@ -2,7 +2,7 @@ package Crypt::PK::X25519;
 
 use strict;
 use warnings;
-our $VERSION = '0.080_006';
+our $VERSION = '0.080_007';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 5.57 'import';
 our %EXPORT_TAGS = ( all => [qw( )] );
@@ -67,7 +67,7 @@ sub import_key {
     return $self->_import_pem($data, $password);
   }
   elsif ($data =~ /^\s*(\{.*?\})\s*$/s) { # JSON
-    my $h = CryptX::_decode_json("$1") // {};
+    my $h = CryptX::_decode_json("$1") || {};
     if ($h->{kty} && $h->{kty} eq "OKP" && $h->{crv} && $h->{crv} eq 'X25519') {
       return $self->_import_raw(decode_b64u($h->{d}), 1) if $h->{d}; # private
       return $self->_import_raw(decode_b64u($h->{x}), 0) if $h->{x}; # public
